aboutsummaryrefslogtreecommitdiffstats
path: root/host/include
diff options
context:
space:
mode:
Diffstat (limited to 'host/include')
-rw-r--r--host/include/uhd/transport/udp_zero_copy.hpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/host/include/uhd/transport/udp_zero_copy.hpp b/host/include/uhd/transport/udp_zero_copy.hpp
index 117f24b2f..c74e6d7b7 100644
--- a/host/include/uhd/transport/udp_zero_copy.hpp
+++ b/host/include/uhd/transport/udp_zero_copy.hpp
@@ -54,18 +54,18 @@ public:
static sptr make(const std::string &addr, const std::string &port);
/*!
* The the rx buffer size on the socket.
* \param num_bytes the new size for the socket buffer
* \return the actual number of bytes allowed by the OS
*/
- virtual size_t set_recv_buff_size(size_t num_bytes) = 0;
+ virtual size_t resize_recv_buff_size(size_t num_bytes) = 0;
/*!
* The the tx buffer size on the socket.
* \param num_bytes the new size for the socket buffer
* \return the actual number of bytes allowed by the OS
*/
- virtual size_t set_send_buff_size(size_t num_bytes) = 0;
+ virtual size_t resize_send_buff_size(size_t num_bytes) = 0;
};
@@ -54,18 +54,18 @@ public:
static sptr make(const std::string &addr, const std::string &port);
/*!
- * The the rx buffer size on the socket.
+ * Resize the the rx buffer size on the socket.
* \param num_bytes the new size for the socket buffer
* \return the actual number of bytes allowed by the OS
@@ -54,18 +54,18 @@ public:
/*!
- * The the tx buffer size on the socket.
+ * Resize the the tx buffer size on the socket.
* \param num_bytes the new size for the socket buffer
* \return the actual number of bytes allowed by the OS